# Introduction

[*PyExoCross*](https://github.com/ExoMol/PyExoCross "PyExoCross") is a Python adaptation of the [*ExoCross*](https://github.com/ExoMol/ExoCross "ExoCross") Fortran application.

*PyExoCross* is designed for postprocessing the huge molecular line lists generated by the ExoMol project and other similar initiatives such as the HITRAN and HITEMP. *PyExoCross* generates absorption and emission spectra and other properties (partition functions, specific heats, cooling functions, lifetimes, oscillator strengths, and stick spectra) based on molecular line lists. *PyExoCross* calculates cross sections with four line profiles: Doppler, Gaussian, Lorentzian, and Voigt; a number of options are available for computing Voigt profiles. *PyExoCross* can convert data format between ExoMol (ExoMol, ExoMolHR, and ExoAtom) and HITRAN (HITRAN and HITEMP). *PyExoCross* supports importing and exporting line lists in the ExoMol and HITRAN formats.

## PyExoCross Python Package

*PyExoCross* ***PyPI*** : [https://pypi.org/project/pyexocross/](https://pypi.org/project/pyexocross/)

*PyExoCross* ***API Reference*** : [https://pyexocross.readthedocs.io/en/latest/python_api/index.html](https://pyexocross.readthedocs.io/en/latest/python_api/index.html)

## PyExoCross Python Program

*PyExoCross* ***GitHub*** : [https://github.com/Beryl-Jingxin/PyExoCross](https://github.com/Beryl-Jingxin/PyExoCross)

*PyExoCross* ***Manual*** : [https://pyexocross.readthedocs.io](https://pyexocross.readthedocs.io)

*PyExoCross* ***Wiki*** : [https://github.com/Beryl-Jingxin/PyExoCross/wiki](https://github.com/Beryl-Jingxin/PyExoCross/wiki)

*PyExoCross* ***NASA EMAC*** : [https://emac.gsfc.nasa.gov?cid=2407-003](https://emac.gsfc.nasa.gov?cid=2407-003)

## PyExoCross Paper

*PyExoCross* ***Published*** Paper : [https://doi.org/10.1093/rasti/rzae016](https://doi.org/10.1093/rasti/rzae016)

*PyExoCross* ***arXiv*** Preprint : [https://arxiv.org/abs/2406.03977](https://arxiv.org/abs/2406.03977)

## Support databases

&#x2705; ExoMol  

&#x2705; ExoAtom

&#x2705; HITRAN

&#x2705; HITEMP

&#x2705; ExoMolHR

&#x23F3; Databases from VAMDC
